Method: DICOM::DClient#move_image

Defined in:
lib/dicom/d_client.rb

#move_image(destination, options = {}) ⇒ Object

Moves a single image to a DICOM server.

This DICOM node must be a third party (i.e. not the client instance you are requesting the move with!).

Instance level attributes for this procedure:

  • ‘0008,0018’ (SOP Instance UID)

  • ‘0008,0052’ (Query/Retrieve Level)

  • ‘0020,000D’ (Study Instance UID)

  • ‘0020,000E’ (Series Instance UID)

Examples:

Move an image from e.q. a PACS to another SCP on the network

node.move_image('SOME_SERVER', '0008,0018' => sop_uid, '0020,000D' => study_uid, '0020,000E' => series_uid)

Parameters:

  • destination (String)

    the AE title of the DICOM server which will receive the file

  • options (Hash) (defaults to: {})

    the options to use for moving the DICOM object

Options Hash (options):

  • 'GGGG,EEEE' (String)

    a tag and value pair to be used for the procedure



296
297
298
299
300
301
302
303
304
305
# File 'lib/dicom/d_client.rb', line 296

def move_image(destination, options={})
  # Study Root Query/Retrieve Information Model - MOVE:
  set_default_presentation_context("1.2.840.10008.5.1.4.1.2.2.2")
  # Transfer the current options to the data_elements hash:
  set_command_fragment_move(destination)
  # Prepare data elements for this operation:
  set_data_fragment_move_image
  set_data_options(options)
  perform_move
end